@@ -24,6 +24,7 @@
 #include <QDialog>
 #include <QVector>
 #include "kdeloggingcategory.h"
+#include "renamecategory.h"
 class QTabWidget;
 class KDEApplicationDebugSettingPage;
 class CustomDebugSettingsPage;
@@ -51,7 +52,8 @@ private:
     void readCategoriesFiles(const QString &path);
     void saveConfig();
     void readConfig();
-    KdeLoggingCategory::List mCategories;
+    KdeLoggingCategory::List mCategoriesList;
+    RenameCategory::List mRenameCategoriesList;
     QTabWidget *mTabWidget;
     KDEApplicationDebugSettingPage *mKdeApplicationSettingsPage;
     CustomDebugSettingsPage *mCustomSettingsPage;
